<?php


class TurkeySMS_SMS {

	private $usercode;
	private $password;
	private $apikey;
	private $title;
	private $charset = '';
	private $startDate;

	public function __construct( $usercode, $password, $apikey, $title = '', $charset = '1' ) { //WP USE
		$this->usercode = trim( $usercode );
		$this->password = trim($password);
		$this->apikey = trim($apikey);
		$this->title = trim($title);
		$this->charset = trim($charset);
	}

	public function sendRequest( $site, $data ) {
		$json = json_encode( $data );
		$ch = curl_init( $site );
		$header = array( 'Content-Type: application/json' );
		curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $ch, CURLOPT_HEADER, false );
		curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
		curl_setopt( $ch, CURLOPT_POST, 1 );
		curl_setopt( $ch, CURLOPT_POSTFIELDS, $json );
		$result = curl_exec( $ch );
		curl_close( $ch );
		return $result;
	}
	
	function turkeysms_db_addlog($sms_id, $type, $phone, $message, $credit, $status, $log_code, $log_message)
	{
		global $wpdb;
		
		$table_name = $wpdb->prefix . 'turkeysms_log';

		$wpdb->insert( 
			$table_name, 
			array( 
				'sms_id' => $sms_id,
				'type' => $type,
				'phone' => $phone,
				'message' => $message,
				'credit' => $credit,
				'status' => $status,
				'log_code' => $log_code, 
				'log_message' => $log_message, 
				'time' => current_time( 'mysql' ) 
			) 
		);
	}



	public function setStartDate( $startDate )

	{

		$this->startDate = $startDate;

	}

	public function getStartDate()

	{

		if ( $this->startDate == '' ) {

			return '';

		}

		return date( 'dmYHi', strtotime( $this->startDate ) );

	}


	public function sendSMS( $phone, $mesaj ) { //WP USE

		$body = array( "api_key" => $this->apikey,
			"title" => $this->title,
			"text" => $mesaj,
			"sentto" => $phone,
			"sms_lang" => $this->charset,
			"report" => 1,
			"response_type" => 'json' );
		$result = $this->sendRequest( 'https://turkeysms.com.tr/api/v3/gonder/add-content', $body );
		$json_result = json_decode( $result );
		
		$this->turkeysms_db_addlog($json_result->sms_id,"SingleSMS", $phone, $mesaj, $json_result->number_of_sms, $json_result->result_code, $json_result->result_code, $json_result->result_message);

		return $json_result;
    }



    /*
     * OTP SMS Gönderimi
     */

    public function sendOTPSMS($phone, $message){
		
		// {"result":true,"otp_code":371751,"sms_id":"17607241","number_of_sms":1,"result_code":"TS-1024","result_message":"The message was sent successfully","sms_lang":"Turkesh","country":"Turkey-TR"}
		
		$body = array("api_key" => $this->apikey,
					  "sms_text"=>$message,
					  "mobile"=> $phone,
					  "title"=> $this->title,
					  "digits"=>"5",
					  "lang"=>$this->charset,
					  "report"=>1,
					  "response_type"=>'json');
		$result = $this->sendRequest('https://turkeysms.com.tr/api/v3/otp_post_detailed/add-content', $body);
		$json_result = json_decode($result);
		
        $this->turkeysms_db_addlog($json_result->sms_id,"OTP_SMS", $phone, $message, $json_result->number_of_sms, $json_result->result_code, $json_result->result_code, $json_result->result_message);
		
        return $json_result;
    }



    public function sendBulkSMS($phones,$message) {      //WP USE
		
		$body = array("api_key" => $this->apikey, 
					  "title"=>$this->title, 
					  "text"=>$message,
					  "sentto"=>$phones,
					  "sms_lang"=>$this->charset,
					  "report"=>1,
					  "response_type"=>'json');
		$result = $this->sendRequest('https://turkeysms.com.tr/api/v3/gonder_coklu_gsm/add-content', $body);
		$json_result = json_decode($result);
		
		
		$phone_dizi = explode(",", $phones);
		foreach ($phone_dizi as $phone) {
			$this->turkeysms_db_addlog($json_result->report_number,"BulkSMS", $phone, $message, $json_result->number_of_sms, $json_result->result_code, $json_result->result_code, $json_result->result_message);
		}
		
        return $this->smsCevap($json_result);

    }



    public function smsCevap($input) {        //WP USE
		
		//{"result":true,"mobile_numbers":2,"report_number":1031687,"number_of_sms":1,"mobiles":[["5376579787","5376579787"]],"result_code":"TS-1024","result_message":"The message was sent successfully","sms_lang":"English","country":"Turkey-TR"}
		
		if($input->result_code=="TS-1024")
		{
			$result = array('durum' => 1, 'kod'=>$input->result_code, 'gorevid'=>$input->report_number, 'mesaj' => $input->result_message);
		}
		else
		{
			$result = array('durum' => 0, 'kod'=>$input->result_code,  'mesaj' => $input->result_message);
		}
		
        return $result;

    }



    public function getSmsBaslik()
	{     //WP USE
		$baslikArray = array();
		$body = array(
			"user_name" => $this->usercode, 
			"user_pass"=>$this->password,
			"report"=>1,
			"response_type"=>'json'
		);
		$result = $this->sendRequest('https://turkeysms.com.tr/api/v3/senderid/add-content', $body);
		$json_result = json_decode($result);
		
		if ($json_result->result==true){
			// D&ouml;nen Baþlýklarý Diziledik
			array_push($baslikArray,$json_result->sender_id);
			// D&ouml;nen Baþlýklarý Geri D&ouml;nd&uuml;r&uuml;yoruz
			return $baslikArray;
		}
		else
		{
			return esc_html__('Gönderici ID bulunamadı. Hata Kodu : ','turkeysmslang').$json_result->result_code.esc_html__(' ve Hata mesajınız : '.$json_result->result_message,'turkeysmslang');
		}
    }



   




    public function turkeysms_GetKredi($user,$pass) {     //WP USE

        
		
		$url_giris = "https://turkeysms.com.tr/api/v3/user_login/login.php?username=$user&password=$pass&response_type=json";
		$json_giris = file_get_contents($url_giris);
		$json_giris = json_decode($json_giris);
		// stdClass Object ( [result] => false [result_code] => TS-1033 [result_message] => The data sent is incorrect )
		// stdClass Object ( [result] => true [result_code] => TS-1024 [result_message] => Login information is correct [api_key] => 1c216b5c38bf0e552138160fbb95062b )
		
		$body_kredi = array("user_name" => $user, "user_pass"=>$pass,"report"=>1,"response_type"=>'json');
		$result_kredi = $this->sendRequest('https://turkeysms.com.tr/api/v3/bakiye/add-content', $body_kredi);
		$json_kredi = json_decode($result_kredi);
		// {"result":"true","result_code":"TS-1040","result_message":"operation_success","api_key":"1c216b5c38bf0e552138160fbb95062b","local_balance_sms":"674","international_balance_tl":"0"}
		// {"result":"false","result_code":"TS-1033","result_message":"The data sent is incorrect"}1
		
		
		if($json_giris->result=="true")
		{
			// API Key Kaydet
			add_option( 'turkeysms_apikey' , $json_giris->api_key );
			// Kredi Kontrol Et
			if($json_kredi->result=="true")
			{
				if($json_kredi->local_balance_sms>0 || $json_kredi->international_balance_tl>0) // Kredi Var Mı?
				{
					$result = array('giris'=>'success', 'durum' => 'success', 'mesaj'=>'', 'kredi' => $json_kredi->local_balance_sms." SMS / ". $json_kredi->international_balance_tl." TL" , 'tipmsj' => esc_html__(" Krediniz ","turkeysmslang"));
				}
				else
				{
					$result = array('giris'=>'success', 'durum' => 'danger', 'mesaj'=> esc_html__('Kredi Satın Al','turkeysmslang'), 'kredi' => $json_kredi->local_balance_sms." SMS / ". $json_kredi->international_balance_tl." TL" , 'tipmsj' => esc_html__('Krediniz Tükendi','turkeysmslang'));
				}
			}
			else
			{
				$result = array('giris'=>'success', 'durum' => 'danger', 'mesaj'=>'', 'kredi' => '', 'tipmsj' => esc_html__(' Krediniz Alınamadı ','turkeysmslang'));
			}
		}
		else{
			$result = array('giris'=>'danger', 'durum' => 'danger', 'mesaj'=>'', 'kredi' => '', 'tipmsj' => esc_html__(' Giriş Başarısız ','turkeysmslang'));
		}
        return $result;

    }



    public function turkeysms_GirisSorgula($user,$pass)    //WP USE
    {

        $response = $this->turkeysms_GetKredi($user,$pass);

        if($response['giris']=='success') {     //Giriş Başarılı

            if($response['durum']=='success') {  //kredi varsa

                $result = array('durum' => 'success',

                    'icon' => 'fa-chech',

                    'mesaj' => "<i class='fa fa-diamond'></i> ".$response['tipmsj']." : ".$response['kredi'],

                    'btnkontrol'=>'enabled',

                    'href'=>'' );

            }

            else{ //kredi yoksa

                $result = array('durum' => 'warning',
                            'icon' => 'fa-shopping-cart',
                            'mesaj' => esc_html__(' Krediniz: ','turkeysmslang').$response['kredi'].esc_html__(' Kredi satın al ','turkeysmslang').'<i class=\'fa fa-external-link\'></i>',
                            'btnkontrol'=>'enabled',
                            'href'=>'https://www.turkeysms.com.tr' );
            }

        }

        else { // Giriş Başarısız

            if(empty($user) && !empty($pass))

               $message = esc_html__('Kullanıdı adı alanı boş','turkeysmslang');

            elseif (empty($pass) && !empty($user))

                $message = esc_html__('Şifre alanı boş','turkeysmslang');

            elseif (empty($user) && empty($pass))

                $message = esc_html__('Kullanıcı adı ve şifre boş.','turkeysmslang');

            else {

                $message = esc_html__('Kullanıcı adı veya şifreniz hatalı.','turkeysmslang');

            }

            $result = array('durum' => 'danger',

                'icon' => 'fa-exclamation-triangle',

                'mesaj' => $message,

                'btnkontrol' => 'disabled',

                'href' => '');

        }

        return json_encode($result);

    }



    private function inboxResponse($data){

        $result = array();

        $result['status']  =  "400";

        $i = 1;

        if($data == 30){

            $result['message'] = " Ge&ccedil;ersiz kullanycy ady , ?ifre veya kullanycynyzyn API eri?im izninin olmady?yny g&ouml;sterir.

Ayryca e?er API eri?iminizde IP synyrlamasy yaptyysanyz ve synyrlady?ynyz ip dy?ynda g&ouml;nderim sa?lyyorsanyz 30 hata kodunu alyrsynyz. API eri?im izninizi veya IP synyrlamanyzy , web aray&uuml;z&uuml;m&uuml;zden; sa? &uuml;st k&ouml;?ede bulunan ayarlar> API i?lemleri men&uuml;sunden kontrol edebilirsiniz.";

        }

        elseif ($data == 40){

            $result['message'] = " G&ouml;sterilecek mesajynyzyn olmady?yny ifade eder. Api ile mesajlarynyzy e?er startdate ve stopdate parametlerini kullanmyyorsanyz sadece bir kere listeyebilirsiniz. Listelenen mesajlar di?er sorgulamalarynyzda gelmez.";

        }

        elseif ($data == 50){

            $result['message'] = " Tarih formaty hatalydyr.";

        }

        elseif ($data == 60){

            $result['message'] = " Arama kiterlerindeki startdate ve stopdate zaman farkynyn 30 g&uuml;nden fazla oldu?unu ifade eder.";

        }

        elseif ($data == 70){

            $result['message'] = " Hataly sorgulama. G&ouml;nderdi?iniz parametrelerden birisi hataly veya zorunlu alanlardan birinin eksik oldu?unu ifade eder.";

        }

        else {

            $parts = explode('<br>
', $data);



            $result['status']  =  "200";



            foreach ($parts as $part) {

                $messages = explode(' | ', $part);

                $result[$i]['phone'] = $messages[0];

                $result[$i]['message'] = $messages[1];

                $result[$i]['time'] = $messages[2];

                $i++;

            }

        }



        return ($result);

    }


    public function phoneToUser($phone, $users){

        $result = array();

        foreach ($users as $user) {

            if($user->billing_phone==$phone){

                $result = $user;

                break;

            }

            else {

                $result = 0;

            }

        }

        return $result;

    }



    /*

     * Netsantral Reporlary

     * Dakikada en fazla 2 kez sorgulanabilir

     */
/*
    public function getVoipReport()

    {

        date_default_timezone_set('Europe/Istanbul');

        $startDate = date('dmYHi', time() - 60*60*24);

        $endDate = date('dmYHi', time());

        $PostAdress = 'https://api.turkeysms.com.tr/netsantral/report/xml';

        $xml = array('body' => "
<?xml version='1.0' encoding="utf-8"?>
<mainbody>
	<header>
		<company>turkeysms</company>
		<usercode>".$this->usercode."</usercode>
		<password>".$this->password."</password>
		<startdate>".$startDate."</startdate>
		<stopdate>".$endDate."</stopdate>
		<version>3</version>
	</header>
</mainbody>
");

        $results = wp_remote_post($PostAdress,$xml);

        $results = $this->responseDecoder($results)['body'];



        if ($results != '' && in_array(trim($results), [100,101])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Dakikada en fazla 2 kez sorgulanabilir.']];

            return json_encode($response,256);

        }

        if ($results != '' && in_array(trim($results), [40])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Son 24 saat i&ccedil;inde listelenecek kayyt yok.']];

            return json_encode($response,256);

        }

        if ($results != '' && in_array(trim($results), [30])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Ge&ccedil;ersiz kullanycy ady, ?ifre veya kullanycynyzyn API eri?im izniniz yok.']];

            return json_encode($response,256);

        }



        if ($results != '' && in_array(trim($results), [50])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Tarih formatynyn hataly.']];

            return json_encode($response,256);

        }



        if ($results != '' && in_array(trim($results), [60])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Zaman farkynyn 7 g&uuml;nden fazla']];

            return json_encode($response,256);

        }



        if ($results != '' && in_array(trim($results), [70])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Hataly sorgulama.']];

            return json_encode($response,256);

        }



        if ($results != '' && in_array(trim($results), [80])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Netsantral hizmeti kullanylmyyor.']];

            return json_encode($response,256);

        }



        $results = explode('<br/>
', $results);



        $response = [];

        foreach ($results as $result) {

            $result = trim($result);

            $cdr = explode('|', $result);

            $temp = [];

            if(isset($cdr[0]) && $cdr[0] != '') {

                $temp['call_id'] = $cdr[0];

                $temp['date'] = $cdr[1];

                $temp['dial_number'] = $cdr[2];

                $temp['caller_number'] = $cdr[3];

                $temp['time'] = $cdr[4];

                $temp['direction'] = $cdr[5];

                //$temp['recording'] = $cdr[6];

                array_push($response, $temp);

            }

        }

        $json['success'] = ['message'=>'Son 24 saatin kayytlary listeleniyor.'];

        $json['data'] = $response;



        return json_encode($json,256);

    }



    /*

     * Santral Raporlary (Sabit Telefon)

     * Dakikada en fazla 2 kez sorgulanabilir

     */
/*
    public function getPhoneReport()

    {

        date_default_timezone_set('Europe/Istanbul');

        $startDate = date('dmYHi', time() - 60*60*24);

        $endDate = date('dmYHi', time());

        $PostAdress = 'https://api.turkeysms.com.tr/voice/report/xml';

        $xml = array('body' => "
<?xml version='1.0'?>
<mainbody>
	<header>
		<company>turkeysms</company>
		<usercode>".$this->usercode."</usercode>
		<password>".$this->password."</password>
		<date></date>
		<direction>4</direction>
	</header>
</mainbody>
");

        $results = wp_remote_post($PostAdress,$xml);

        $results = $this->responseDecoder($results)['body'];





        if ($results != '' && in_array(trim($results), [100,101])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Dakikada en fazla 2 kez sorgulanabilir.']];

            return json_encode($response,256);

        }

        if ($results != '' && in_array(trim($results), [40])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Son 24 saat i&ccedil;inde listelenecek kayyt yok.']];

            return json_encode($response,256);

        }

        if ($results != '' && in_array(trim($results), [30])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Ge&ccedil;ersiz kullanycy ady, ?ifre veya kullanycynyzyn API eri?im izniniz yok.']];

            return json_encode($response,256);

        }



        if ($results != '' && in_array(trim($results), [50])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Tarih formatynyn hataly.']];

            return json_encode($response,256);

        }



        if ($results != '' && in_array(trim($results), [70])){

            $response = ['error'=>['code'=>trim($results), 'message'=>'Hataly sorgulama.']];

            return json_encode($response,256);

        }





        $results = explode('<br/>
', $results);



        $response = [];

        foreach ($results as $result) {

            $result = trim($result);

            $cdr = explode(' | ', $result);

            $temp = [];

            if(isset($cdr[0]) && $cdr[0] != '') {

                $temp['caller_number'] = $cdr[0];

                $temp['date'] = $cdr[1];

                $temp['time'] = $cdr[2];

                $temp['direction'] = $cdr[3];

                array_push($response, $temp);

            }

        }

        $json['success'] = ['message'=>'Bug&uuml;n&uuml;n kayytlary listeleniyor.'];

        $json['data'] = $response;



        return json_encode($json,256);

    }

*/

    public function setContact($datas, $groupName = 'Opencart')

    {

        if (count($datas)>500){

            $contacts = array_chunk($datas, 500);



            foreach ($contacts as $key=>$contact) {

                $this->addContacts($contact, $groupName);

            }

        } else {

            return $this->addContacts($datas, $groupName);

        }

        return true;

    }



    public function turkeysms_yaz($data, $file = 'cf7dosya1.txt'){

        touch($file);

        $dosya = fopen($file, 'w');

        fwrite($dosya, print_r($data, TRUE));

        fclose($dosya);

    }



    


    public function getphoneClear($phone){

        $unwanted = array(' ', '+', '(', ')', '.', '-', '&amp;', 'nbsp;'  );

        $replace    = array('', '', '', '', '', '', '', '' );

        $result      = str_replace($unwanted, $replace, $phone);

        return $result;

    }



    public function timeconvert($time){

        if($time<60){

            $second = ceil($time);

            if($second<10){

                $second = '0'.$second;

            }

            return '00:00:'.$second;

        }

        $minute = floor($time/60);

        $second = $time%60;

        if($minute<60){

            if($minute<10){

                $minute = '0'.$minute;

            }

            if($second<10){

                $second = '0'.$second;

            }

            return '00:'.$minute.':'.$second;

        }

        $hour = floor($minute/60);

        $minute = $minute%60;

        if($hour<10){

            $hour = '0'.$hour;

        }

        if($minute<10){

            $minute = '0'.$minute;

        }

        if($second<10){

            $second = '0'.$second;

        }

        return $hour.':'.$minute.':'.$second;

    }



    private function responseDecoder($response)

    {

        if (is_array($response) && !empty($response['body']))

        {

            return $response;

        }

        $array['body'] = '';

        return $array;

    }

}