<?php

/*
Plugin Name: TurkeySMS
Plugin URI: https://wordpress.org/plugins/turkeysms/
Description: TurkeySMS hesabınız ile giriş yaparak SMS tabanlı Woocommerce yönetimi sağlayabilir, bireysel veya toplu SMS gönderimleri sağlayabilirsiniz. Son eklediğimiz özellik ile Contact Form 7 formuna başvuru yapan kişilere de SMS gönderimi sağlayabilirsiniz.
Author: TurkeySMS Bilişim
Author URI: www.turkeysms.com.tr
Version: 0.1.1.0
*/


/**

 * Copyright (c) 2021 TurkeySMS Tüm hakları saklıdır.
 *
 * Released under the GPL license
 * http://www.opensource.org/licenses/gpl-license.php
 *
 * This is an add-on for WordPress
 * http://wordpress.org/
 *
 */

    if ( !defined( 'ABSPATH' ) ) exit;

    define( 'PLUGIN_CLASS_PATH', dirname(__FILE__). '/includes' );

	// Language Settings
	load_plugin_textdomain("turkeysmslang",false,dirname(plugin_basename(__FILE__))."/languages/");

    require_once PLUGIN_CLASS_PATH.'/turkeysms_sms.php';

    require_once PLUGIN_CLASS_PATH.'/replacefunction.php';

	

    @ini_set('log_errors','On');
    @ini_set('display_errors','On');
    @ini_set('error_log','turkeysms_error.log'); // path to server-writable log file
	
	// Menü Eklemesi Yapıyoruz
    add_action("admin_menu", "turkeysms_addMenuu");

    function turkeysms_addMenuu()
    {
        add_menu_page(esc_html__('TurkeySMS - www.turkeysms.com.tr','turkeysmslang'), 
					  esc_html__('TurkeySMS','turkeysmslang'),
					  'edit_pages', 
					  "turkeysms-wp-plugin", 
					  "turkeysms_index",
					  plugins_url( 'lib/image/turkeysms.png', __FILE__ )
					 );
    }



	function plugin_name_get_version() {

		$plugin_data = get_plugin_data( __FILE__ );
		$plugin_version = $plugin_data['Version'];
		return $plugin_version;
	}



    function turkeysms_index()
    {
        require_once ('pages/index.php');
    }


	// Eklenti Stil Yüklemelerini Yapıyoruz
    add_action( 'admin_enqueue_scripts', 'turkeysms_loadcustomstyle' );

    function turkeysms_loadcustomstyle($hook)
    {

        if($hook!= 'toplevel_page_turkeysms-wp-plugin') {
            return;
        }

        $plugin_url = plugin_dir_url( __FILE__ );

        wp_enqueue_style( 'bootstrap',      $plugin_url . 'lib/css/bootstrap.css' );
        wp_enqueue_style( 'font-awesome',   $plugin_url . '/lib/fonts/css/font-awesome.min.css' );
        wp_enqueue_style( 'style',         $plugin_url . 'lib/css/style.css' );
        wp_enqueue_style( 'sweetalert2',    $plugin_url . 'lib/js/sweetalert2/dist/sweetalert2.css' );
        wp_enqueue_style( 'dataTables',    $plugin_url . 'lib/css/bootstrap-table.min.css' );
		
		$lang = get_bloginfo("language");
		if ($lang=="ar")
		{
			wp_enqueue_style( 'bootstrap-rtl',    $plugin_url . 'lib/css/bootstrap.rtl.min.css?ver=3.3.7' );
		}

    }


	// Eklenti JS Yüklemelerini Yapıyoruz
    add_action( 'admin_enqueue_scripts','turkeysms_script');

    function turkeysms_script()
    {
       wp_register_script('bootstrapminjs', plugins_url('bootstrap.min.js', dirname(__FILE__).'/lib/js/1/'));
       wp_enqueue_script('bootstrapminjs');
       wp_register_script('sweet2', plugins_url('sweetalert2.all.js', dirname(__FILE__).'/lib/js/sweetalert2/dist/1/'));
       wp_enqueue_script('sweet2');
       wp_register_script('table', plugins_url('bootstrap-table.min.js', dirname(__FILE__).'/lib/js/1/'));
       wp_enqueue_script('table');
    }

	// Veritabanını Oluşturuyoruz
	register_activation_hook( __FILE__, 'db_install' );
	global $turkeysms_db_version;
	$turkeysms_db_version = '1.0';

	function db_install() {
		global $wpdb;
		global $turkeysms_db_version;

		$table_name = $wpdb->prefix . 'turkeysms_log';

		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE $table_name (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			type varchar(10) NOT NULL,
			sms_id varchar(20) NOT NULL,
			phone varchar(20) NOT NULL,
			message text NULL,
			credit mediumint(10) NULL,
			status varchar(10) NOT NULL,
			log_code varchar(20) NOT NULL,
			log_message text NOT NULL,
			time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
			PRIMARY KEY  (id)
		) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );

		add_option( 'turkeysms_db_version', $turkeysms_db_version );
	}


    function my_settings_sanitize($input){

        $replace = new ReplaceFunction();

        $input = $replace->turkeysms_spaceTrim($input);

        return $input;

    }



    add_action('admin_init', 'turkeysms_options');

    function turkeysms_options()

    {

        register_setting('turkeysmsoptions', 'turkeysms_user', 'my_settings_sanitize');

        register_setting('turkeysmsoptions', 'turkeysms_pass');
		
		register_setting('turkeysmsoptions', 'turkeysms_apikey');

        register_setting('turkeysmsoptions', 'turkeysms_input_smstitle');



        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_admin_control');

        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_admin_no');

        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_admin_text');

        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_customer_control');

        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_customer_text');



        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_admin_control');

        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_admin_no');

        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_admin_text');

        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_customer_control');

        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_customer_text');



        register_setting('turkeysmsoptions', 'turkeysms_newnote1_to_customer_control');

        register_setting('turkeysmsoptions', 'turkeysms_newnote1_to_customer_text');



        register_setting('turkeysmsoptions', 'turkeysms_newnote2_to_customer_control');

        register_setting('turkeysmsoptions', 'turkeysms_newnote2_to_customer_text');



        register_setting('turkeysmsoptions', 'turkeysms_order_refund_to_admin_control');

        register_setting('turkeysmsoptions', 'turkeysms_order_refund_to_admin_no');

        register_setting('turkeysmsoptions', 'turkeysms_order_refund_to_admin_text');





        register_setting('turkeysmsoptions', 'turkeysms_product_waitlist1_control');

        register_setting('turkeysmsoptions', 'turkeysms_product_waitlist1_text');







        register_setting('turkeysmsoptions', 'turkeysms_rehber_control');

        register_setting('turkeysmsoptions', 'turkeysms_rehber_groupname');



        register_setting('turkeysmsoptions', 'turkeysms_orderstatus_change_customer_control');



        register_setting('turkeysmsoptions', 'turkeysms_status');

        register_setting('turkeysmsoptions', 'turkeysms_charset');



        register_setting('turkeysmsoptions', 'turkeysms_order_status_query_control');

        register_setting('turkeysmsoptions', 'turkeysms_order_status_query_prefix');

        register_setting('turkeysmsoptions', 'turkeysms_order_status_query_text');

        register_setting('turkeysmsoptions', 'turkeysms_order_status_query_error_text');

        register_setting('turkeysmsoptions', 'turkeysms_order_status_query_token');

        register_setting('turkeysmsoptions', 'turkeysms_order_status_query_link');



        //JSON settings

        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_admin_json');

        register_setting('turkeysmsoptions', 'turkeysms_newuser_to_customer_json');

        register_setting('turkeysmsoptions', 'turkeysms_newnote1_to_customer_json');

        register_setting('turkeysmsoptions', 'turkeysms_newnote2_to_customer_json');

        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_admin_json');

        register_setting('turkeysmsoptions', 'turkeysms_neworder_to_customer_json');

        register_setting('turkeysmsoptions', 'turkeysms_order_refund_to_admin_json');

        register_setting('turkeysmsoptions', 'turkeysms_product_waitlist1_json');



        //OTP SMS

        register_setting('turkeysmsoptions', 'turkeysms_tf2_auth_register_control');

        register_setting('turkeysmsoptions', 'turkeysms_tf2_auth_register_text');

        register_setting('turkeysmsoptions', 'turkeysms_tf2_auth_register_diff');



        //otp duplicate control

        register_setting('turkeysmsoptions', 'turkeysms_tf2_auth_register_phone_control');

        register_setting('turkeysmsoptions', 'turkeysms_tf2_auth_register_phone_warning_text');



        //contacts meta

        register_setting('turkeysmsoptions', 'turkeysms_contact_meta_key');



        //roles

        register_setting('turkeysmsoptions', 'turkeysms_auth_roles');

        register_setting('turkeysmsoptions', 'turkeysms_auth_users');

        register_setting('turkeysmsoptions', 'turkeysms_auth_roles_control');

        register_setting('turkeysmsoptions', 'turkeysms_auth_users_control');



        register_setting('turkeysmsoptions', 'turkeysms_phonenumber_zero1');

        register_setting('turkeysmsoptions', 'turkeysms_licence_key_to_meta');



        //ÇIKIŞ

        register_setting('turkeysmsoptionslogout', 'turkeysms_user');

        register_setting('turkeysmsoptionslogout', 'turkeysms_pass');
		
		register_setting('turkeysmsoptionslogout', 'turkeysms_apikey');



        if(function_exists('wc_get_order_statuses')) {

            $order_statuses = wc_get_order_statuses();

            $arraykeys = array_keys($order_statuses);

            foreach ($arraykeys as $arraykey) {

                register_setting('turkeysmsoptions','turkeysms_order_status_text_'.$arraykey);

                register_setting('turkeysmsoptions','turkeysms_order_status_text_'.$arraykey.'_json');

            }

        }



        register_setting('turkeysmsoptions','turkeysms_cf7_success_customer_control');

        register_setting('turkeysmsoptions','turkeysms_cf7_success_admin_control');

        register_setting('turkeysmsoptions','turkeysms_cf7_contact_control');



        register_setting('turkeysmsoptions','turkeysms_cf7_to_admin_no');

        $cf7_list = apply_filters( 'turkeysms_contact_form_7_list', '');

        foreach ($cf7_list as $item) {

            register_setting('turkeysmsoptions','turkeysms_cf7_list_text_success_customer_'.$item->ID);

            register_setting('turkeysmsoptions','turkeysms_cf7_list_text_success_admin_'.$item->ID);

            register_setting('turkeysmsoptions','turkeysms_cf7_list_contact_'.$item->ID);

            register_setting('turkeysmsoptions','turkeysms_cf7_list_contact_firstname_'.$item->ID);

            register_setting('turkeysmsoptions','turkeysms_cf7_list_contact_lastname_'.$item->ID);

            register_setting('turkeysmsoptions','turkeysms_cf7_list_text_error_'.$item->ID);

        }

    }



    function turkeysms_getCustomSetting($key, $search){

        $settings  = esc_html(get_option($key));

        if ($settings != ''){

            $jsonData = stripslashes(html_entity_decode($settings));

            $object = json_decode($jsonData, true);

            if (isset($object[$search])){

                return $object[$search];

            } else {

                return '';

            }

        }

        return $settings;

    }



    add_action( 'admin_footer', 'turkeysms_ajaxRequest' );

    function turkeysms_ajaxRequest() { ?>

        <script type="text/javascript" >

            function privatesmsSend(number="") {

                var phone = document.getElementById('private_phone').value;

                var message = document.getElementById('private_text').value;

                if (phone =="" || message =="")

                {

                    swal('<?php echo esc_html__('Mesaj göndermek için lütfen gerekli alanları doldurun.','turkeysmslang')?>');

                    return;

                }

                document.getElementById('sendSMS').disabled = true;

                var data = {

                    'action': 'turkeysms_sendsms',
                    'phone': phone,
                    'message':message

                };

                jQuery.post(ajaxurl, data, function(response) {
					
                   var obje = JSON.parse(response);
					
                        if(obje.result==true){

                            document.getElementById('private_phone').value="";

                            document.getElementById('private_text').value="";

                            swal({

                                title: "<?php echo esc_html__('BAŞARILI','turkeysmslang')?>",

                                html: obje.number_of_sms+ ' kredi<br><br><b>' + phone + '</b> numarasına ' + '"<b>'+message+'</b>" gönderildi.',

                                type: 'success'

                            });

                        }

                        else{

                            swal({

                                title: "<?php echo esc_html__('HATA! Kod : ','turkeysmslang')?>"+ obje.result_code,

                                text: obje.result_message,

                                type: 'error'

                            });

                        }

                    document.getElementById('sendSMS').disabled = false;

                });

            }

            function turkeysms_sendSMS_bulkTab(id="") {
				
                document.getElementById('bulkSMSbtn').disabled = true;

                var users = [];

                var numberstext;

                if (id!=""){

                    users = id; numberstext="<?php echo esc_html__('numarasına','turkeysmslang')?>";

                }

                else {

                    var table = jQuery('#table');

                    var sonuc = table.bootstrapTable('getAllSelections');

                    for (var i=0 ; i<sonuc.length ; i++)

                    {

                        users += sonuc[i][1]+",";

                    }

                    numberstext="<?php echo esc_html__('numaralarına','turkeysmslang')?>";

                }



                var mark='<mark class="bulkmark" onclick="varfill2(this.innerHTML);">';

                var variables = mark+'[uye_adi]</mark> &nbsp'+mark+'[uye_soyadi]</mark> &nbsp'+mark+'[uye_telefonu]</mark> &nbsp'+mark+'[uye_epostasi]</mark> &nbsp'+mark+'[kullanici_adi]</mark>&nbsp'+mark+'[tarih]</mark>&nbsp'+mark+'[saat]</mark>';

                if(users!="") {

                    swal({

                        title: "<?php echo esc_html__('Mesaj','turkeysmslang')?>",

                        input: 'textarea',

                        inputPlaceholder:'<?php echo esc_html__('Mesaj İçeriğini buraya giriniz.','turkeysmslang')?>',

                        confirmButtonText : '<?php echo esc_html__('Gönder','turkeysmslang')?>',

                        cancelButtonText : '<?php echo esc_html__('İptal','turkeysmslang')?>',

                        confirmButtonColor : '#2ECC71',

                        cancelButtonColor : '#E74C3C',

                        width: 650,

                        showCancelButton: true,

                        showLoaderOnConfirm: true,

                        footer: '<i class="fa fa-angle-double-right"></i> <?php echo esc_html__('Kullanabileceğiniz Değişkenler :','turkeysmslang')?> ' + variables,

                        preConfirm: function (text) {

                            return new Promise(function (resolve, reject) {

                                if (text) {

                                    var message = text;

                                    var data = {

                                        'action': 'turkeysms_sendSMS_bulkTab',

                                        'users': users,

                                        'message':message

                                    };

                                    jQuery.post(ajaxurl, data, function (response) {
                                        var obje = JSON.parse(response);



                                        if (obje.durum == 1) {

                                            swal({

                                                title: "<?php echo esc_html__('BAŞARILI!','turkeysmslang')?>",

                                                html: obje.mesaj+ '<br><br><b>' + obje.phones + '</b> '+numberstext+' "<b>'+message+'</b>" gönderildi.',

                                                type: 'success'

                                            });

                                        }

                                        else{

                                            swal({

                                                title: "<?php echo esc_html__('HATA! Kod :','turkeysmslang')?> "+ obje.kod,

                                                text: obje.mesaj,

                                                type: 'error'

                                            });

                                        }

                                    });

                                } else {

                                    swal({

                                        title: "<?php echo esc_html__('Mesaj içeriğini boş bıraktınız.','turkeysmslang')?>",

                                        text: "<?php echo esc_html__('Lütfen SMS göndermek için birşeyler yazın.','turkeysmslang')?>",

                                        type: 'error',

                                    });

                                }

                                document.getElementById('bulkSMSbtn').disabled = false;

                            })

                        }

                    })

                }

                else {

                    swal('<?php echo esc_html__('Mesaj göndermek için müşteri seçmelisiniz.','turkeysmslang')?>');

                    return;

                }

            }

            function sendSMSglobal(phone) {

                if(!jQuery.isNumeric(phone)){

                    swal({

                        title: "<?php echo esc_html__('Uyarı!','turkeysmslang')?>",

                        text: '<?php echo esc_html__('Sadece telefon numaralarına SMS gönderilebilir.','turkeysmslang')?>',

                        type: 'error'

                    });

                    return false;

                }

                if(phone!="") {

                    swal({

                        title: "<?php echo esc_html__('Mesaj','turkeysmslang')?>",

                        input: 'textarea',

                        inputPlaceholder:'<?php echo esc_html__('Mesaj İçeriğini buraya giriniz.','turkeysmslang')?>',

                        confirmButtonText : '<?php echo esc_html__('Gönder','turkeysmslang')?>',

                        cancelButtonText : '<?php echo esc_html__('İptal','turkeysmslang')?>',

                        confirmButtonColor : '#2ECC71',

                        cancelButtonColor : '#E74C3C',

                        width: 650,

                        showCancelButton: true,

                        showLoaderOnConfirm: true,

                        footer: '<?php echo esc_html__('Kayıtlı olmayan bir numaraya sms atıyorsunuz.','turkeysmslang')?>',

                        preConfirm: function (text) {

                            return new Promise(function (resolve, reject) {

                                if (text) {

                                    var message = text;

                                    var data = {

                                        'action': 'turkeysms_sendsms',

                                        'phone': phone,

                                        'message':message

                                    };

                                    jQuery.post(ajaxurl, data, function (response) {

                                        var obje = JSON.parse(response);



                                        if (obje.durum == 1) {

                                            swal({

                                                title: "<?php echo esc_html__('BAŞARILI!','turkeysmslang')?>",

                                                html: obje.mesaj+ '<br><br><b>' + phone + '</b> numarasına ' + '"<b>'+message+'</b>" gönderildi.',

                                                type: 'success'

                                            });

                                        }

                                        else{

                                            swal({

                                                title: "<?php echo esc_html__('HATA! Kod : ','turkeysmslang')?>"+ obje.kod,

                                                text: obje.mesaj,

                                                type: 'error'

                                            });

                                        }

                                    });

                                } else {

                                    swal({

                                        title: "<?php echo esc_html__('Mesaj içeriğini boş bıraktınız.','turkeysmslang')?>",

                                        text: "<?php echo esc_html__('Lütfen sms göndermek için birşeyler yazın.','turkeysmslang')?>",

                                        type: 'error',

                                    });

                                }

                                document.getElementById('bulkSMSbtn').disabled = false;

                            })

                        }

                    })

                }

                else {

                    swal('<?php echo esc_html__('Mesaj göndermek için müşteri seçmelisiniz.','turkeysmslang')?>');

                    return;

                }

            }

            function varfill2(degisken) {

                var textarea = document.getElementsByClassName('swal2-textarea')[0];

                var start = textarea.selectionStart;

                var end = textarea.selectionEnd;

                var finText = textarea.value.substring(0, start) + degisken + textarea.value.substring(end);

                textarea.value = finText;

                textarea.focus();

                textarea.selectionEnd= end + (degisken.length);

            }

            jQuery(document).keyup(function(e) {

                if (e.keyCode == 27) {

                    hideLoadingMessage();

                    errorControl = 1;

                    xhr.abort();

                }

            });

            jQuery('#contactsMove').click(function () {

                var groupName = jQuery('#contactsBulk').val();

                if(groupName == ''){

                    swal({

                        title: "<?php echo esc_html__('BAŞARISIZ!','turkeysmslang')?>",

                        html: '<?php echo esc_html__('Aktarım için grup ismi girilmelidir.','turkeysmslang')?>',

                        type: 'error',

                    });

                    return false;

                }

                showLoadingMessage('<?php echo esc_html__('Kayıtlar aktarılıyor...','turkeysmslang')?>');

                var data = {

                    'action': 'turkeysms_addtoGroup',

                    'copy' :1,

                    'groupName':groupName

                };

                jQuery.post(ajaxurl, data, function (response) {

                    var response = JSON.parse(response);

                    if (response['result']=='success') {

                        swal({

                            title: "<?php echo esc_html__('BAŞARILI!','turkeysmslang')?>",

                            html: response['resultmsg'],

                            type: response["result"],

                        });

                    }

                    else

                    {

                        swal({

                            title: "<?php echo esc_html__('HATA!','turkeysmslang')?>",

                            text:  response['resultmsg'],

                            type: response["result"],

                        });

                    }

                    hideLoadingMessage();

                });



            })





        </script> <?php

    }



    add_action( 'wp_ajax_turkeysms_addtoGroup', 'turkeysms_addtoGroup' );

    function turkeysms_addtoGroup()

    {

        $users = get_users();



        $phone_meta = 'billing_phone';

        if (get_option("turkeysms_contact_meta_key") != ''){

            $phone_meta = get_option("turkeysms_contact_meta_key");

        }



        $contacts = []; $tmp = [];

        foreach ($users as $result) {

            $tmp['telephone'] = get_user_meta( $result->ID, $phone_meta, true );

            if ($tmp['telephone'] == ''){

                continue;

            }

            $tmp['firstname'] = $result->first_name;

            $tmp['lastname'] = $result->last_name;

            array_push($contacts, $tmp);

        }



        $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"), get_option("turkeysms_pass"), get_option("turkeysms_apikey"), get_option('turkeysms_input_smstitle'), get_option("turkeysms_charset"));

        $groupName = 'Wordpress';

        if(isset($_POST['groupName'])){

            $groupName =$_POST['groupName'];

        }



        $moving = $turkeysms->setContact($contacts, $groupName);

        echo json_encode(['result'=>'success', 'resultmsg'=>'Toplam <b>'.count($contacts).'</b> kullanıcı <b>'.$groupName.'</b> grubuna aktarıldı.']);

        wp_die();

    }



    add_filter( 'turkeysms_contact_form_7_list', 'turkeysms_wpcf7_form_list' );

    function turkeysms_wpcf7_form_list($arg='') {

        $list = get_posts(array(

            'post_type'     => 'wpcf7_contact_form',

            'numberposts'   => -1

        ));



        return  $list;

    }



    add_action( 'wp_ajax_turkeysms_sendSMS_bulkTab', 'turkeysms_sendSMS_bulkTab' );

    function turkeysms_sendSMS_bulkTab() {

        $phones = "";

        $json   = array();

        $phone_meta = 'billing_phone';

        if (get_option("turkeysms_contact_meta_key") != ''){

            $phone_meta = get_option("turkeysms_contact_meta_key");

        }

        if(isset($_POST['users']) && isset($_POST['message'])) {

            $users      = explode(',',rtrim(sanitize_text_field($_POST['users']),','));

            $bulkBody   = "";

            $replace    = new ReplaceFunction();

            foreach ($users as $userID) {

                $phones    .= $replace->turkeysms_spaceTrim(get_user_meta( $userID, $phone_meta, true )).",";

                $userinfo   = get_userdata($userID);

                $data       = array('first_name'=> $userinfo->first_name,   'last_name'=> $userinfo->last_name,

                                    'user_login'=> $userinfo->user_login,   'phone'=>get_user_meta($userID, $phone_meta, true),

                                    'user_email' =>$userinfo->user_email,   'message'=> wp_unslash($_POST['message']));

                $message = $replace->turkeysms_replace_bulksms($data);

                $message = $replace->turkeysms_replace_date($message);

                $bulkBody  .= '<mp><msg><![CDATA[' . $message . ']]></msg><no>' . $data['phone'] . '</no></mp>';

            }

            $phones = rtrim($phones,',');

            $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"), get_option("turkeysms_pass"), get_option("turkeysms_apikey"), get_option('turkeysms_input_smstitle'), get_option("turkeysms_charset"));

            $json = $turkeysms->sendBulkSMS($phones,$_POST['message']);

            $json['phones'] = $phones;

        }

        else {

            $json['durum'] = '0';

            $json['mesaj'] = esc_html__('Sms gönderimi başarısız.','turkeysmslang');

        }

        echo json_encode($json);

        wp_die();

    }



    add_action( 'wp_ajax_turkeysms_sendsms', 'turkeysms_sendsms' );

    function turkeysms_sendsms() {

        $json = array();

        $replace = new ReplaceFunction();

        if(isset($_POST['phone']) && isset($_POST['message'])){

            $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"),get_option("turkeysms_pass"),get_option("turkeysms_apikey"),get_option('turkeysms_input_smstitle'), get_option("turkeysms_charset"));

            $json = $turkeysms->sendSMS(sanitize_text_field($replace->turkeysms_spaceTrim($_POST['phone'])), wp_unslash($_POST['message']));

        }

        else {

            $json['result'] = '0';
            $json['sms_status'] = esc_html__('Sms gönderimi başarısız.','turkeysmslang');
        }

        echo json_encode($json);
        wp_die();

    }



    function turkeysms_newcustomer_control()
    {

        $newuser1       = esc_html(get_option("turkeysms_newuser_to_admin_control"));
        $newuser2       = esc_html(get_option("turkeysms_newuser_to_customer_control"));
        $newuser3       = esc_html(get_option("turkeysms_rehber_control"));
        $newuser4       = esc_html(get_option("turkeysms_tf2_auth_register_control"));

        $control        = 0;

        if(isset($newuser1) && !empty($newuser1) && $newuser1==1) {
            $control=1;
        }
        else if(isset($newuser2) && !empty($newuser2) && $newuser2==1) {
            $control=2;
        }
        else if(isset($newuser3) && !empty($newuser3) && $newuser3==1) {
            $control=3;
        }
        else if(isset($newuser4) && !empty($newuser4) && $newuser4==1) {
            $control = 4;
        }
        return $control;

    }



    add_action( 'woocommerce_register_form', 'turkeysms_custom_register_form' );

    function turkeysms_custom_register_form() {

        $turkeysms_status  = esc_html(get_option("turkeysms_status"));

        $turkeysms_phonenumber_zero  = esc_html(get_option("turkeysms_phonenumber_zero1"));

        $control        = turkeysms_newcustomer_control();

        $otpregister_control = esc_html(get_option("turkeysms_tf2_auth_register_control"));

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 && ($control!=0 || $otpregister_control ==1))

        {

            ?><p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">

            <label for="first_name"><?php _e('Adınız', 'turkeysmslang') ?><span class="required">*</span><br/>

                <input type="text" name="first_name" id="first_name" class="input-text form-control"

                       value="<?php echo sanitize_text_field($_POST['first_name'])?>" required/></label>

            </p>

            <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">

            <label for="last_name"><?php _e('Soyadınız', 'turkeysmslang') ?><span

                        class="required">*</span><br/>

                <input type="text" name="last_name" id="last_name" class="input-text form-control"

                       value="<?php echo sanitize_text_field($_POST['last_name'])?>" required/></label>

            </p>

            <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">

            <label for="billing_phone"><?php _e('Cep Telefonu', 'turkeysmslang') ?><span

                        class="required">*</span><br/>

                <input type="tel" name="billing_phone" id="billing_phone" class="input-text form-control"

                       value="<?php if($turkeysms_phonenumber_zero==1){echo '0';}?><?php echo sanitize_text_field($_POST['billing_phone'])?>" required/>

                <?php

                $turkeysms_status  = esc_html(get_option("turkeysms_status"));

                if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 ) {



                    if ($otpregister_control == 1) {

                        ?>

                        <input type="button" name="sendCode" id="sendCode" class="input-text" onclick="sendtf2Code(jQuery('#billing_phone').val());"

                               value="<?php echo esc_html__('Doğrulama kodu gönder','turkeysmslang')?>"/>

                        <?php

                    }

                }

                ?>



            </label>

            </p>

            <?php

            $turkeysms_status  = esc_html(get_option("turkeysms_status"));

            if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 ) {

                $otpregister_control = esc_html(get_option("turkeysms_tf2_auth_register_control"));

                if ($otpregister_control == 1) {

                    ?>

                    <p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">

                        <label for="tf2Code"><?php _e('Doğrulama Kodu:', 'turkeysmslang') ?><span

                                    class="required">*</span><br/>

                            <input type="text" name="tf2Code" id="tf2Code" class="input-text form-control"

                                   value="" required/>

                            <label for=""><i><small id="tf2Codealert"></small></i></label>

                        </label>



                    </p>

                    <?php

                }

            }

        }

    }



    add_action( 'woocommerce_register_form', 'turkeysms_ajaxRegister' );

    function turkeysms_ajaxRegister() {

        $turkeysms_phonenumber_zero  = esc_html(get_option("turkeysms_phonenumber_zero1"));

        ?>

        <script type="text/javascript" >

            function sendtf2Code(phone) {

                var firstname = jQuery('#first_name').val();

                var lastname = jQuery('#last_name').val();

                var email = jQuery("input[name*='email']").val();



                var error = '';

                if(firstname == '') {

                    error += '>'+ '<?php echo esc_html__('İsim girilmedi','turkeysmslang') ?>'+'\n';

                }

                if(lastname == '') {

                    error += '>'+ '<?php echo esc_html__('Soyisim girilmedi','turkeysmslang') ?>'+'\n';

                }

                if(email == '') {

                    error += '> '+ '<?php echo esc_html__('E-Mail adresi girilmedi','turkeysmslang') ?>'+'\n';

                }

                if(phone == '') {

                    error += '> '+ '<?php echo esc_html__('Telefon numarası girilmedi','turkeysmslang') ?>'+'\n';

                }



                <?php

                if ($turkeysms_phonenumber_zero==1){

                    ?>

                if(phone.slice( 0,1 ) !='0'){

                    error += '> '+ '<?php echo esc_html__('Telefon numarası 0 ile başlamalıdır','turkeysmslang') ?>'+'\n';

                }

                <?php

                }

                ?>



                if (error != ''){

                    alert("<?php echo esc_html__('Aşağıdaki hatalar meydana geldi:','turkeysmslang') ?>"+" \n\n"+ error);

                    return false;

                }



                var data = {

                    'action': 'turkeysms_sendtf2SMS',

                    'phone': phone,

                    'first_name': firstname,

                    'last_name': lastname,

                    'email':email

                };



                jQuery.post(ajaxurl, data, function(response) {
                    var endChar = response.substring(response.length-1);

                    if (endChar == '0'){

                        response = response.substring(0,(response.length-1));

                    }

                    var obje = JSON.parse(response);
					
                    if(obje.status == 'success'){

                        alert(obje.phone+' <?php echo esc_html__('numaralı telefonunuza gelen güvenlik kodunu giriniz.','turkeysmslang') ?>'+' ');

                        jQuery('#tf2Codealert').html('*Lütfen '+obje.phone+' numaralı telefonunuza gelen '+obje.refno+' referans numaralı güvenlik kodunu giriniz.');

                        document.getElementById("tf2Code").focus();

                        jQuery('#sendCode').prop('disabled', true);

                    } else {

                        if (obje.status == 'error' && obje.state == 1){

                            alert(obje.data + ' <?php echo esc_html__('Lütfen site yöneticisi ile iletişime geçin.','turkeysmslang') ?>');

                        } else if(obje.status == 'error' && obje.state == 2) {

                            alert(obje.data);

                        }else if(obje.status == 'error' && obje.state == 4){

                            alert(obje.data);

                        }else if(obje.status == 'error' && obje.state == 5){

                            alert(obje.data);

                        } else {

                            alert('<?php echo esc_html__('Bilinmeyen bir hata oluştu. GSM numarası girdiğinize emin olun. Sorunun devam etmesi halinde lütfen site yöneticisi ile iletişime geçin.','turkeysmslang') ?>');

                        }

                    }

                });

            }

            </script>

        <?php

    }



    add_action( 'wp_ajax_turkeysms_sendtf2SMS', 'turkeysms_sendtf2SMS' );

    function turkeysms_sendtf2SMS(){

        $authKey = rand(10000, 99999);

        $refno = substr(md5(uniqid()),0,5);

        $phone = sanitize_text_field($_POST['phone']);

        ltrim($phone, '0');

        $replace = new ReplaceFunction();



        $phone_control = get_option('turkeysms_tf2_auth_register_phone_control');

        if($phone_control == 1){

            $args = array (

                'order' => 'DESC',

                'orderby' => 'ID',

                'number'=>1,    //limit

                'meta_query' => array(

                    'relation' => 'OR',

                    array(

                        'key'     => 'billing_phone',

                        'value'   => trim($_POST['phone'], '0'),

                        'compare' => 'LIKE'

                    )

                )

            );

            $query = new WP_User_Query($args);

            $results = $query->get_results();

            if (is_array($results) && $results != null && isset($results[0])){  // kayıtlı numara var

                $phone_warning_text = get_option('turkeysms_tf2_auth_register_phone_warning_text');

                $newVar = [];

                $oldVar = [];

                array_push($oldVar, '[telefon_no]');

                array_push($oldVar, '[ad]');

                array_push($oldVar, '[soyad]');

                array_push($oldVar, '[mail]');



                $newVar['telefon_no'] = sanitize_text_field($_POST['phone']);

                $newVar['ad'] = sanitize_text_field($_POST['first_name']);

                $newVar['soyad'] = sanitize_text_field($_POST['last_name']);

                $newVar['mail'] = sanitize_text_field($_POST['email']);



                $phone_warning_text = $replace->turkeysms_replace_array($oldVar, $newVar, $phone_warning_text);

                echo json_encode(['status'=>'error','state'=>'5', 'data'=>$phone_warning_text]);

                die;

            } else {

            }

        }



        $turkeysms_status  = esc_html(get_option("turkeysms_status"));

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 ){

            if ($phone != '' && in_array(strlen($phone),[10,11])){

                $otpregister_control = esc_html(get_option("turkeysms_tf2_auth_register_control"));

                if ($otpregister_control == 1){

                    $first_name = sanitize_text_field($_POST['first_name']);

                    $last_name = sanitize_text_field($_POST['last_name']);

                    $email = sanitize_text_field($_POST['email']);
					
                    $code = get_post_meta(1, $phone.'_2fa', true);



                    date_default_timezone_set('Europe/Istanbul');

                    if ($code != ''){

                        $sendTime = get_post_meta(1, $phone.'_2fa_time', true);

                        $sendTime = strtotime($sendTime);

                        $now =  time();

                        $diff = $now - $sendTime;



                        $savedDiff  = esc_html(get_option("turkeysms_tf2_auth_register_diff"));

                        if ($savedDiff == '' || is_int($savedDiff)){

                            $savedDiff = 180;

                        }

                        if ($diff > $savedDiff * 60) {

                            update_post_meta( 1, $phone.'_2fa', $authKey );

                            update_post_meta( 1, $phone.'_2fa_time',  date('Y-m-d H:i:s', time()) );

                            update_post_meta( 1, $phone.'_2fa_ref',  $refno );

                        } else {

                            $savedRefNo = get_post_meta(1, $phone.'_2fa_ref', true);

                            echo json_encode(['status'=>'error','state'=>4, 'data'=>'Daha önce '.$phone.' numarasına '.$savedRefNo.' referans numaralı doğrulama kodu gönderilmiş. Lütfen gönderilmiş güvenlik kodunu girin.'.' Gönderme zamanı: '.date('d.m.Y H:i', $sendTime), 'phone'=>$phone]);

                            die;

                        }

                    } else {

                        add_post_meta(1, $phone.'_2fa', $authKey, '');

                        add_post_meta(1, $phone.'_2fa_time', date('Y-m-d H:i:s', time()));

                        add_post_meta(1, $phone.'_2fa_ref', $refno);

                    }



                    $data  = array(

                            'first_name'=> $first_name,

                            'last_name'=> $last_name,

                            'phone'=>$phone,

                            'user_email' =>$email,

                            'otpcode'=> $authKey,

                            'refno' => $refno,

                            'message'=> (get_option("turkeysms_tf2_auth_register_text"))

                    );

                    $message = $replace->turkeysms_replace_twofactorauth_text($data);

                    $message = $replace->turkeysms_replace_date($message);



                    $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"),get_option("turkeysms_pass"),get_option("turkeysms_apikey"),get_option('turkeysms_input_smstitle'), get_option("turkeysms_charset"));
					
					$result = $turkeysms->sendOTPSMS(sanitize_text_field($replace->turkeysms_spaceTrim($phone)), wp_unslash($message));
					
					if($result->result_code=="TS-1024")
					{
						echo json_encode(['status'=>'success', 'data'=>esc_html__('Doğrulama gönderildi.','turkeysmslang'), 'phone'=>sanitize_text_field($replace->turkeysms_spaceTrim($phone)), 'refno'=>$refno]);
					}
					else {

                        update_post_meta( 1, $phone.'_2fa_time',  '1970-01-01 12:12:12' );
                        echo json_encode(['status'=>'error', 'state'=>'1', 'data'=>esc_html__('Doğrulama kodu gönderilemedi ','turkeysmslang')]);
                    }
                } else {

                    echo json_encode(['status'=>'error','state'=>'3', 'data'=>esc_html__('OTP kontrol açık değil.','turkeysmslang')]);

                }

            } else {

                echo json_encode(['status'=>'error','state'=>'2', 'data'=>esc_html__('Telefon numarası hatalı','turkeysmslang')]);

            }

        }

    }



    add_action('wp_enqueue_scripts', 'turkeysms_admin_scripts');

    add_action('wp_ajax_nopriv_turkeysms_sendtf2SMS', 'turkeysms_sendtf2SMS');

    function turkeysms_admin_scripts() {

        $turkeysms_status  = esc_html(get_option("turkeysms_status"));

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 ){

            $otpregister_control = esc_html(get_option("turkeysms_tf2_auth_register_control"));

            if ($otpregister_control == 1){

                wp_enqueue_script( 'script', plugins_url('ajax.js', dirname(__FILE__).'/lib/js/1/'), array('jquery'), '1.0', true );

                wp_localize_script('script', 'ajaxurl', admin_url( 'admin-ajax.php' ) );

            }

        }

    }



    add_filter( 'woocommerce_process_registration_errors', 'turkeysms_custom_registration_errors', 10, 1 ); //telefon numarası girilmemişse

    function turkeysms_custom_registration_errors( $validation_error) {

        $turkeysms_status  = esc_html(get_option("turkeysms_status"));

        $billing_phone  = sanitize_text_field($_POST['billing_phone']);

        $first_name     = sanitize_text_field($_POST['first_name']);

        $last_name      = sanitize_text_field($_POST['last_name']);

        $control        = turkeysms_newcustomer_control();



        $turkeysms_status  = esc_html(get_option("turkeysms_status"));

        $otpstatus = false;

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 ) {

            $otpregister_control = esc_html(get_option("turkeysms_tf2_auth_register_control"));

            if ($otpregister_control == 1) {

                $otpstatus = true;

            }

        }



        $tf2Code = '';

        $code = '';

        if ($otpstatus){

            $tf2Code        = sanitize_text_field($_POST['tf2Code']);

            $code = get_post_meta(1, $billing_phone.'_2fa', true);

        }

        $turkeysms_phonenumber_zero  = esc_html(get_option("turkeysms_phonenumber_zero1"));

        $delete = true;

        if($code != $tf2Code && $otpstatus==true ){

            $validation_error->add('tf2Code_error', __('<strong></strong>'.esc_html__('Doğrulama kodunu yanlış girdiniz!','turkeysmslang'), 'mydomain'));

            $delete = false;

        } else {

            if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 && $control!=0)

            {

                if(isset($first_name) && empty($first_name) || trim($first_name) == ''){

                    $validation_error->add('first_name_error', '<strong></strong>'.esc_html__('Adınızı giriniz','turkeysmslang'));

                    $delete = false;

                }

                if(isset($last_name) && empty($last_name) || trim($last_name) == ''){

                    $validation_error->add('last_name_error', '<strong></strong>'.esc_html__('Soyadınızı giriniz','turkeysmslang'));

                    $delete = false;

                }

                if(isset($billing_phone) && empty($billing_phone) || trim($billing_phone) == ''){

                    $validation_error->add('billing_phone_error', '<strong></strong>'.esc_html__('Telefon numaranızı giriniz','turkeysmslang'));

                    $delete = false;

                }

                if ($turkeysms_phonenumber_zero == 1){

                    if (substr($billing_phone, 0, 1) != 0){

                        $validation_error->add('billing_phone_error', '<strong></strong>'.esc_html__('Telefon numaranızın başında 0 olmalıdır','turkeysmslang'));

                        $delete = false;

                    }

                }

            }

        }

        if ($delete = true){

            delete_post_meta(1, $billing_phone.'_2fa', $code);

            delete_post_meta(1, $billing_phone.'_2fa_time');

            delete_post_meta(1, $billing_phone.'_2fa_ref');

        }



        return $validation_error;

    }



    add_action( 'woocommerce_created_customer', 'turkeysms_newcustomer', 10, 3 );

    function turkeysms_newcustomer($customer_id){



        $newuser1       = esc_html(get_option("turkeysms_newuser_to_admin_control"));

        $newuser2       = esc_html(get_option("turkeysms_newuser_to_customer_control"));

        $newuser3       = esc_html(get_option("turkeysms_rehber_control"));

        $control        = turkeysms_newcustomer_control();

        $billing_phone  = "";

        $billing_phone  = sanitize_text_field($_POST['billing_phone']);



        if (isset($_POST['first_name'])){

            $first_name= sanitize_text_field($_POST['first_name']);

        }else {

            $first_name= sanitize_text_field($_POST['billing_first_name']);

        }



        if (isset($_POST['last_name'])){

            $last_name      = sanitize_text_field($_POST['last_name']);

        }else {

            $last_name      = sanitize_text_field($_POST['billing_last_name']);

        }



        $turkeysms_status  = esc_html(get_option("turkeysms_status"));

        $replace        = new ReplaceFunction();





        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 && $control!=0){

            update_user_meta($customer_id, 'billing_phone', $billing_phone);

            update_user_meta($customer_id, 'first_name', $first_name);

            update_user_meta($customer_id, 'last_name', $last_name);



            $custom_settings_admin = turkeysms_getCustomSetting('turkeysms_newuser_to_admin_json', '_timecondition');

            $custom_settings_customer = turkeysms_getCustomSetting('turkeysms_newuser_to_customer_json', '_timecondition');



            /*if(empty($first_name)){

                update_user_meta($customer_id, 'first_name', sanitize_text_field($_POST['billing_first_name']), '');

            }

            if (empty($last_name)){

                update_user_meta($customer_id, 'last_name', sanitize_text_field($_POST['billing_last_name']), '');

            }*/

            $userinfo       = get_userdata($customer_id);

            if (isset($newuser1) && !empty($newuser1) && $newuser1 == 1) {   //admine mesaj

                $phone      = esc_html(get_option('turkeysms_newuser_to_admin_no'));

                $data       = array('first_name'=> $first_name,   'last_name'=> $last_name,

                                    'user_login'=> $userinfo->user_login,   'phone'=>$billing_phone, 'user_email' =>$userinfo->user_email,

                                    'message'=> (get_option('turkeysms_newuser_to_admin_text')));

                $message    = $replace->turkeysms_replace_newuser_to_text($data);

                $message = $replace->turkeysms_replace_date($message);



                turkeysms_sendSMS_oneToMany($phone, $message, ['startDate'=>$custom_settings_admin]);

            }

            if (isset($newuser2) && !empty($newuser2) && $newuser2 == 1) {   //müşteriye mesaj

                $data       = array('first_name'=> $first_name,   'last_name'=> $last_name,

                                    'user_login'=> $userinfo->user_login,   'phone'=>$billing_phone, 'user_email' =>$userinfo->user_email,

                                    'message'=> (get_option('turkeysms_newuser_to_customer_text')));

                $message    = $replace->turkeysms_replace_newuser_to_text($data);

                $message = $replace->turkeysms_replace_date($message);

                turkeysms_sendSMS_oneToMany($billing_phone, $message, ['startDate'=>$custom_settings_customer]);

            }

            if (isset($newuser3) && !empty($newuser3) && $newuser3 == 1) {   //rehbere kayıt

                turkeysms_add_contact($customer_id);

            }

        }

    }



    add_action('lmfwc_event_post_order_license_keys','turkeysms_new_licance', 10,1);

    function turkeysms_new_licance($id)
    {
        $turkeysms_status = esc_html(get_option("turkeysms_status"));

        $turkeysms_licence_key_to_meta  = esc_html(get_option("turkeysms_licence_key_to_meta"));

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 && $turkeysms_licence_key_to_meta == 1 ) {

            $licences = [];

            foreach ($id['licenses'] as $item) {

                $licence = apply_filters('lmfwc_decrypt', $item->getLicenseKey());

                array_push($licences, $licence);

            }

            $keys = implode(' , ', $licences);
			
            add_post_meta($id['orderId'], '_licence_keys', $keys, '');
        }
    }



    //payment_complete ve thankyou kancalarının çalışmaması durumlarında özel kanca çalıştır(ayarlanmalı.)

    $turkeysms_new_order_custom_action = turkeysms_getCustomSetting('turkeysms_neworder_to_admin_json', '_otherAction');



    if ( $turkeysms_new_order_custom_action != '' ){

        add_action( $turkeysms_new_order_custom_action, 'turkeysms_new_order_custom_action', 10,3 );

    } else {

        add_action( 'woocommerce_payment_complete', 'turkeysms_new_order_send_sms', 10,1 );   //yeni siparişte sms gönder

        add_action( 'woocommerce_thankyou', 'turkeysms_new_order_send_sms', 10,1 );   //yeni siparişte sms gönder

    }

    function turkeysms_new_order_custom_action( $order_id, $data, $order){

        turkeysms_new_order_send_sms($order_id);

    }



    add_action( 'wp_insert_post', 'turkeysms_new_order_admin_panel', 10, 1 );

    function turkeysms_new_order_admin_panel( $post_id ) {

        if (function_exists('wc_get_order')){

            $order = wc_get_order( $post_id );

            if (method_exists($order, 'get_billing_phone') && $order->get_billing_phone() != '') {

                $custom_settings_admin = turkeysms_getCustomSetting('turkeysms_neworder_to_admin_json', '_addOrderAdminPanel');

                $custom_settings_customer = turkeysms_getCustomSetting('turkeysms_neworder_to_customer_json', '_addOrderAdminPanel');

                if($custom_settings_admin == 1){

                    turkeysms_new_order_send_sms($post_id, 1);

                }

                if($custom_settings_customer == 1){

                    turkeysms_new_order_send_sms($post_id, 2);

                }

            }

        }

    }



    function turkeysms_new_order_send_sms($order_id, $adminpanel = 0){

        if( get_post_meta( $order_id, '_new_order_turkeysms', true ) && $adminpanel==0 ){   // eğer daha önce bu sipariş zaten oluşmuşsa bu fonksiyon dursun
            return; // sipariş zaten alınmış.
        }

        add_post_meta($order_id, '_new_order_turkeysms', 'yes', '');

        if(function_exists('wc_get_order')) {

            $order2 = wc_get_order( $order_id );

            $items = $order2->get_items();

            $products_info ="";

            foreach ($items as $item) {

                $products_info .= $item->get_name()."(".$item->get_subtotal().'TLx'.$item->get_quantity()."), ";

            }

            $products_info = rtrim($products_info,' ,');

        }

        else{

            $products_info="";

        }

        $neworder1       = esc_html(get_option("turkeysms_neworder_to_admin_control"));

        $neworder2       = esc_html(get_option("turkeysms_neworder_to_customer_control"));

        $control         = turkeysms_neworder_control();

        $turkeysms_status   = esc_html(get_option("turkeysms_status"));

        $order           = new WC_Order( $order_id );

        $userinfo        = get_userdata($order->customer_id);

        $replace         = new ReplaceFunction();



        $custom_settings_admin = turkeysms_getCustomSetting('turkeysms_neworder_to_admin_json', '_timecondition');

        $custom_settings_customer = turkeysms_getCustomSetting('turkeysms_neworder_to_customer_json', '_timecondition');

        $custom_settings_customer_private_phone_key = turkeysms_getCustomSetting('turkeysms_neworder_to_customer_json', '_custom_phone_key');





        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1 && $control!=0) {

            if (isset($neworder1) && !empty($neworder1) && $neworder1 == 1 && (in_array($adminpanel, [0,1]))) {   //admine mesaj

                $phone      = esc_html(get_option('turkeysms_neworder_to_admin_no'));

                $username = explode('@', $order->billing_email);

                $data   = array(

                            'order_id'=>$order_id,

                            'total'=>$order->total,

                            'first_name'=> $order->billing_first_name,

                            'last_name'=> $order->billing_last_name,

                            'user_login'=> $username[0],

                            'phone'=>$order->billing_phone,

                            'user_email' =>$order->billing_email,

                            'items' => $products_info,

                            'message'=> (get_option('turkeysms_neworder_to_admin_text'))

                );

                $message = $replace->turkeysms_replace_neworder_to_text($data);

                $message = $replace->turkeysms_replace_order_meta_datas($order, $message);

                $metadatas = get_post_meta($order_id);

                $message = $replace->turkeysms_replace_order_meta_datas2($metadatas, $message);

                $message = $replace->turkeysms_replace_order_add_datas($order, $message, 'data', '[data:');

                $message = $replace->turkeysms_replace_date($message);

                turkeysms_sendSMS_oneToMany($phone, $message, ['startDate'=>$custom_settings_admin]);

            }



            if (isset($neworder2) && !empty($neworder2) && $neworder2 == 1  && (in_array($adminpanel, [0,2]))) {   //müşteriye mesaj

                $order = wc_get_order( $order_id );

                $phone_key = 'billing_phone';

                if ($custom_settings_customer_private_phone_key != ''){

                    $phone_key = $custom_settings_customer_private_phone_key;

                }

                $sendsmsphone = '';

                if (isset($order->{$phone_key})){

                    $sendsmsphone = $order->{$phone_key};

                }

                if ($sendsmsphone == '' || !is_numeric($sendsmsphone)){

                    $sendsmsphone = $order->billing_phone;

                }

                $data   = array(

                            'order_id'=>$order_id,

                            'total'=>$order->total,

                            'first_name'=> $order->billing_first_name,

                            'last_name'=> $order->billing_last_name,

                            'user_login'=> $username[0],

                            'phone'=> $sendsmsphone,

                            'user_email' =>$order->billing_email,

                            'items' => $products_info,

                            'message'=> (get_option('turkeysms_neworder_to_customer_text'))

                );

                $message    = $replace->turkeysms_replace_neworder_to_text($data);

                $message = $replace->turkeysms_replace_order_meta_datas($order, $message);

                $metadatas = get_post_meta($order_id);

                $message = $replace->turkeysms_replace_order_meta_datas2($metadatas, $message);

                $message = $replace->turkeysms_replace_order_add_datas($order, $message, 'data', '[data:');

                $message = $replace->turkeysms_replace_date($message);

                turkeysms_sendSMS_oneToMany($sendsmsphone, $message,['startDate'=>$custom_settings_customer]);

            }

        }

    }



                                                        //120---            cancelled---            completed

    function turkeysms_order_status_changed( $this_get_id, $this_status_transition_from, $this_status_transition_to, $instance ) {

        turkeysms_order_status_changed_sendSMS($this_get_id, 'turkeysms_order_status_text_wc-'.$this_status_transition_to, $this_status_transition_to);



    };

    add_action( 'woocommerce_order_status_changed', 'turkeysms_order_status_changed', 10, 4 );



    add_action('woocommerce_order_status_cancelled', 'turkeysms_order_status_cancelled');

    function turkeysms_order_status_cancelled($order_id)
    {

        $control         = esc_html(get_option("turkeysms_order_refund_to_admin_control"));

        $message         = (get_option("turkeysms_order_refund_to_admin_text"));

        $phones          = esc_html(get_option("turkeysms_order_refund_to_admin_no"));

        $turkeysms_status   = esc_html(get_option("turkeysms_status"));

        $replace         = new ReplaceFunction();

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1) {

            if (isset($control) && !empty($control) && $control == 1) {

                if (isset($message) && !empty($message)) {

                    $custom_settings_cancelled_timecondition = turkeysms_getCustomSetting('turkeysms_order_refund_to_admin_json', '_timecondition');



                    $order           = new WC_Order( $order_id );

                    $userinfo        = get_userdata($order->customer_id);

                    $data       = array('order_id'=>$order_id, 'first_name'=> $userinfo->first_name,   'last_name'=> $userinfo->last_name,

                        'user_login'=> $userinfo->user_login,   'phone'=> $order->billing_phone, 'user_email' =>$userinfo->user_email,

                        'message'=> $message);

                    $message    = $replace->turkeysms_replace_order_status_changes($data);

                    $message = $replace->turkeysms_replace_order_meta_datas($order, $message);

                    $metadatas = get_post_meta($order_id);

                    $message = $replace->turkeysms_replace_order_meta_datas2($metadatas, $message);

                    $message = $replace->turkeysms_replace_date($message);

                    turkeysms_sendSMS_oneToMany($phones, $message, ['startDate'=>$custom_settings_cancelled_timecondition]);

                }

            }

        }

       // turkeysms_order_status_changed_sendSMS($order_id, 'turkeysms_order_status_text_wc-cancelled');

    }



    add_filter( 'woocommerce_customer_save_address', 'turkeysms_customereditaddres', 10, 2 );  //fatura adresi değişip telefon numnarası girildiyse rehbere ekler

    function turkeysms_customereditaddres($user_id){

        turkeysms_add_contact($user_id);

    }



    function turkeysms_sendSMS_oneToMany($phone, $message, $settings=[])
    {

        $replace = new ReplaceFunction();

        $json = array();

        if(isset($phone) && isset($message) && !empty($phone) && !empty($message)){

            $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"), get_option("turkeysms_pass"), get_option("turkeysms_apikey"), get_option("turkeysms_input_smstitle"), get_option("turkeysms_charset"));

            if (isset($settings['startDate']) && $settings['startDate'] != '' && is_numeric(intval($settings['startDate']))){

                $turkeysms->setStartDate(date('Y-m-d H:i', current_time( 'timestamp' ) + ($settings['startDate']*60)));

            }

            $json = $turkeysms->sendSMS($replace->turkeysms_spaceTrim($phone), $message);

        }

        else {

            $json['sms_status'] = '0';

            $json['mesaj'] = esc_html__('SMS gönderimi başarısız.','turkeysmslang');

        }

        return json_encode($json);

    }



    function turkeysms_neworder_control()
    {

        $neworder1       = esc_html(get_option("turkeysms_neworder_to_admin_control"));

        $neworder2       = esc_html(get_option("turkeysms_neworder_to_customer_control"));

        $control         = 0;

        if(isset($neworder1) && !empty($neworder1) && $neworder1==1) {

            $control=1;

        }

        elseif(isset($neworder2) && !empty($neworder2) && $neworder2==1) {

            $control=2;

        }

        return $control;

    }



    function turkeysms_add_contact($customer_id)
    {

        $grupcontrol    = esc_html(get_option('turkeysms_rehber_control'));

        $groupname      = esc_html(get_option('turkeysms_rehber_groupname'));

        $userinfo       = get_userdata($customer_id);

        if(isset($grupcontrol) && !empty($grupcontrol) && $grupcontrol==1) {

            $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"), get_option("turkeysms_pass"), get_option("turkeysms_apikey"), get_option('turkeysms_input_smstitle'), get_option("turkeysms_charset"));

            if($userinfo->first_name=="")

                $firstname = "nickname";

            else

                $firstname = $userinfo->first_name;



            if($userinfo->last_name=="")

                $lastname = $userinfo->nickname;

            else

                $lastname = $userinfo->last_name;

            $replace = new ReplaceFunction();

            $turkeysms->addContact($firstname, $lastname, $replace->turkeysms_spaceTrim($userinfo->billing_phone), $groupname);

        }

    }



    function turkeysms_order_status_changed_sendSMS($order_id, $text, $this_status_transition_to)
    {

        $control         = esc_html(get_option("turkeysms_orderstatus_change_customer_control"));

        $message         = (get_option($text));

        $turkeysms_status   = esc_html(get_option("turkeysms_status"));

        $replace         = new ReplaceFunction();





        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1) {

            if (isset($control) && !empty($control) && $control == 1) {

                if (isset($message) && !empty($message)) {

                    $order           = new WC_Order( $order_id );

                    $userinfo        = get_userdata($order->customer_id);

                    $trackingCode = '';

                    $trackingCompany = '';

                    foreach ($order->meta_data as $meta_datum) {

                        if ($meta_datum->key == 'kargo_takip_no'){

                            $trackingCode = $meta_datum->value;

                        }

                        if ($meta_datum->key == 'kargo_firmasi'){

                            $trackingCompany = $meta_datum->value;

                        }

                    }

                    if ((isset($userinfo->user_login) && $userinfo->user_login != '')){

                        $user_login = $userinfo->user_login;

                    } else {

                        $user_login = $order->shipping_first_name.$order->shipping_last_name;

                    }





                    $custom_settings_changed_timecondition = turkeysms_getCustomSetting('turkeysms_order_status_text_wc-'.$this_status_transition_to.'_json', '_timecondition');

                    $custom_settings_customer_private_phone_key = turkeysms_getCustomSetting('turkeysms_order_status_text_wc-'.$this_status_transition_to.'_json', '_custom_phone_key');



                    $phone_key = 'billing_phone';

                    if ($custom_settings_customer_private_phone_key != ''){

                        $phone_key = $custom_settings_customer_private_phone_key;

                    }

                    $sendsmsphone='';

                    if (isset($order->{$phone_key})){

                        $sendsmsphone = $order->{$phone_key};

                    }

                    if ($sendsmsphone == '' || !is_numeric($sendsmsphone)){

                        $sendsmsphone = $order->billing_phone;

                    }



                    $data       = array('order_id'=>$order_id, 'first_name'=> $order->shipping_first_name,   'last_name'=> $order->shipping_last_name,

                        'user_login'=> $user_login,   'phone'=> $sendsmsphone, 'user_email' =>$order->billing_email,

                        'message'=> $message, 'trackingCompany'=>$replace->turkeysms_replace_shipping_company($trackingCompany), 'trackingCode'=>$trackingCode);

                    $message    = $replace->turkeysms_replace_order_status_changes($data);

                    $message = $replace->turkeysms_replace_order_meta_datas($order, $message);

                    $metadatas = get_post_meta($order_id);

                    $message = $replace->turkeysms_replace_order_meta_datas2($metadatas, $message);

                    $message = $replace->turkeysms_replace_order_add_datas($order, $message, 'data', '[data:');

                    $message = $replace->turkeysms_replace_date($message);

                    turkeysms_sendSMS_oneToMany($sendsmsphone, $message, ['startDate'=>$custom_settings_changed_timecondition]);

                }

            }

        }

    }



    add_action( 'woocommerce_new_order_note_data', 'turkeysms_new_order_note_data', 10, 2 );

    function turkeysms_new_order_note_data( $args, $args2 ) {

        //type 0  == note1 = Özel Not -- turkeysms_newnote1_to_customer_control -- turkeysms_newnote1_to_customer_text

        //type  1 == note2 = Müşteriye not --



        $order_id = $args['comment_post_ID'];

        $type = $args2['is_customer_note'];
		
        $note = $args['comment_content'];



        $status_note1 = esc_html(get_option("turkeysms_newnote1_to_customer_control"));

        $status_note2 = esc_html(get_option("turkeysms_newnote2_to_customer_control"));



        if (!empty($status_note1) && $status_note1==1 && $type == 0){   //özel sms

            $customermessage = esc_html(get_option("turkeysms_newnote1_to_customer_text"));

            $options = 'turkeysms_newnote1_to_customer_json';

            turkeysms_new_order_note_sendSMS($order_id, $type, $note, $customermessage, $options);
        }



        if (!empty($status_note2) && $status_note2==1 && $type == 1){ //müşteriye sms

            $customermessage = esc_html(get_option("turkeysms_newnote2_to_customer_text"));

            $options = 'turkeysms_newnote2_to_customer_json';

            turkeysms_new_order_note_sendSMS($order_id, $type, $note, $customermessage, $options);

        }

        return $args;

    }





function turkeysms_new_order_note_sendSMS($order_id, $note_type, $note, $customermessage, $optionskey)
    {

        $turkeysms_status   = esc_html(get_option("turkeysms_status"));

        $replace         = new ReplaceFunction();

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1) {

            if (isset($customermessage) && !empty($customermessage)) {

                $order           = new WC_Order( $order_id );

                $userinfo        = get_userdata($order->customer_id);



                if ((isset($userinfo->user_login) && $userinfo->user_login != '')){

                    $user_login = $userinfo->user_login;

                } else {

                    $user_login = $order->shipping_first_name.$order->shipping_last_name;

                }



                $custom_settings_changed_timecondition = turkeysms_getCustomSetting($optionskey, '_timecondition');

                $custom_settings_customer_private_phone_key = turkeysms_getCustomSetting($optionskey, '_custom_phone_key');



                $phone_key = 'billing_phone';

                if ($custom_settings_customer_private_phone_key != ''){

                    $phone_key = $custom_settings_customer_private_phone_key;

                }

                $sendsmsphone='';

                if (isset($order->{$phone_key})){

                    $sendsmsphone = $order->{$phone_key};

                }

                if ($sendsmsphone == '' || !is_numeric($sendsmsphone)){

                    $sendsmsphone = $order->billing_phone;

                }



                $data       = array('order_id'=>$order_id, 'first_name'=> $order->billing_first_name,   'last_name'=> $order->billing_last_name,

                    'user_login'=> $user_login,   'phone'=> $sendsmsphone, 'user_email' =>$order->billing_email, 'note'=> $note,

                    'message'=> $customermessage, 'total'=>$order->total);

                $message    = $replace->turkeysms_replace_add_note($data);

                $message = $replace->turkeysms_replace_date($message);

                turkeysms_sendSMS_oneToMany($sendsmsphone, $message, ['startDate'=>$custom_settings_changed_timecondition]);

            }

        }

    }



    function turkeysms_yaz($data, $file = 'cf7dosya1.txt'){

        touch($file);

        $dosya = fopen($file, 'w');

        fwrite($dosya, print_r($data, TRUE));

        fclose($dosya);

    }





    /*

     * WAITLIST STOK İŞLEMLERİ START

     */



    /*

     * Normal ürünlerin stok değişimini dinleyerek stoğa girmesi durumunda waitlist listesine SMS gönderir.

     */

    function turkeysms_product_set_stock( $product ) {

        turkeysms_set_stock_trigger($product);

    };

    add_action( 'woocommerce_product_set_stock', 'turkeysms_product_set_stock', 10, 1 );



    /*

     * Varyasyonlu ürünlerin stok değişimini dinleyerek stoğa girmesi durumunda waitlist listesine SMS gönderir.

     */

    function turkeysms_product_set_stock_variation($product){

        turkeysms_set_stock_trigger($product);

    }

    add_action( 'woocommerce_variation_set_stock', 'turkeysms_product_set_stock_variation', 10, 1 );



    /*

     * Stok değişikliğini dinleyerek bekleme listesine sms gönderimini tetikleyecek fonksiyon

     */

    function turkeysms_set_stock_trigger($product)
    {

        $productId  = $product->get_data()['id'];

       // $limit = wc_get_low_stock_amount( $product );

       // $new_stock = $product->get_changes()['stock_quantity'];

       // $old_stock = $product->get_data()['stock_quantity'];



        if (isset($product->get_changes()['stock_status']) && $product->get_changes()['stock_status']=='instock'){

            if (class_exists('Pie_WCWL_Waitlist')) {

                $waitlist = new Pie_WCWL_Waitlist($product);

                $users = $waitlist->waitlist;

                foreach ($users as $customerId => $date) {

                    turkeysms_waitlist_send_sms($customerId, $productId);

                }

            }

        }

    }



    /*

     * waitlist listesine mail gönderildiğinde SMS de gönderir.

     */

    function turkeysms_waitlist_push($customerId, $productId)
    {

        turkeysms_waitlist_send_sms($customerId, $productId);

    }

    add_action( 'wcwl_mailout_send_email', 'turkeysms_waitlist_push', 10, 2 );



    /*

     * Bekleme listelerine SMS gönderimi sağlayan fonksiyondur.

     */

    function turkeysms_waitlist_send_sms($customerId,$productId)
    {

        $control         = esc_html(get_option("turkeysms_product_waitlist1_control"));

        $message         = esc_html(get_option("turkeysms_product_waitlist1_text"));;

        $turkeysms_status   = esc_html(get_option("turkeysms_status"));

        $replace         = new ReplaceFunction();

        $product =  wc_get_product($productId);

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1) {

            if (isset($control) && !empty($control) && $control == 1) {

                if (isset($message) && !empty($message)) {

                    $customer = new WC_Customer($customerId);

                    $product =  wc_get_product($productId);





                    $custom_settings_changed_timecondition = turkeysms_getCustomSetting('turkeysms_product_waitlist1_json', '_timecondition');

                    $custom_settings_customer_private_phone_key = turkeysms_getCustomSetting('turkeysms_product_waitlist1_json', '_custom_phone_key');



                    $phone_key = 'billing_phone';

                    if ($custom_settings_customer_private_phone_key != ''){

                        $phone_key = $custom_settings_customer_private_phone_key;

                    }



                    $sendsmsphone='';

                    if ($customer->{$phone_key} != ''){

                        $sendsmsphone = $customer->{$phone_key};

                    }



                    if ($sendsmsphone == '' || !is_numeric($sendsmsphone)){

                        $sendsmsphone = $customer->billing_phone;

                    }



                    $newVar = [];

                    $oldVar = [];

                    array_push($oldVar, '[uye_adi]');

                    array_push($oldVar, '[uye_soyadi]');

                    array_push($oldVar, '[uye_telefonu]');

                    array_push($oldVar, '[uye_epostasi]');

                    array_push($oldVar, '[kullanici_adi]');

                    array_push($oldVar, '[urun_kodu]');

                    array_push($oldVar, '[urun_adi]');

                    array_push($oldVar, '[stok_miktari]');



                    $newVar['uye_adi'] = sanitize_text_field($customer->first_name);

                    $newVar['uye_soyadi'] = sanitize_text_field($customer->last_name);

                    $newVar['uye_telefonu'] = sanitize_text_field($customer->billing_phone);

                    $newVar['uye_epostasi'] = sanitize_text_field($customer->email);

                    $newVar['kullanici_adi'] = sanitize_text_field($customer->display_name);

                    $newVar['urun_kodu'] = sanitize_text_field($product->sku);

                    $newVar['urun_adi'] = sanitize_text_field($product->name);

                    $newVar['stok_miktari'] = sanitize_text_field($product->stock);



                    $message = $replace->turkeysms_replace_array($oldVar, $newVar, $message);



                    $message = $replace->turkeysms_meta_data_replace($customer->data, $message, '[meta_user:');

                    $message = $replace->turkeysms_meta_data_replace($product->get_data(), $message, '[meta_product:');

                    $message = $replace->turkeysms_replace_date($message);

                    turkeysms_sendSMS_oneToMany($sendsmsphone, $message, ['startDate'=>$custom_settings_changed_timecondition]);

                }

            }

        }

    }



    /*

     * WAITLIST STOK İŞLEMLERİ END

     */



    //contact form 7 açık seçeneklerin smsleri gönderilir. sadece başarılı yanıt aldığında gönderiyor.

    add_action( 'wpcf7_mail_sent', 'turkeysms_cf7_form_submit', 10, 1 );

    function turkeysms_cf7_form_submit( $contact_form ) {

        $title = $contact_form->title;

        $submission = WPCF7_Submission::get_instance();

        $phone_customer = '';

        $phone_admin = esc_html(get_option('turkeysms_cf7_to_admin_no'));



        if ( $submission ) {

            $posted_data = $submission->get_posted_data();

        }

        $form_id = 0;

        if(isset($posted_data['_wpcf7']) && $posted_data['_wpcf7']>0){

            $form_id = $posted_data['_wpcf7'];

        } else {

            $form_id = $contact_form->id;

        }



        $turkeysms_status   = esc_html(get_option("turkeysms_status"));

        if(isset($turkeysms_status) && !empty($turkeysms_status) && $turkeysms_status==1) {

            if (isset($posted_data)) {

                $customer_control = esc_html(get_option('turkeysms_cf7_success_customer_control'));

                if (isset($customer_control) && !empty($customer_control) && $customer_control == 1) {

                    $customer_message = (get_option('turkeysms_cf7_list_text_success_customer_' . $form_id));

                    $phone_customer = $posted_data['telephone'];

                    if ($phone_customer != '') {

                        if ($customer_message != '') {

                            $replace = new ReplaceFunction();

                            $message = $replace->turkeysms_cf7_replace_all_var($posted_data, $customer_message);

                            $message = $replace->turkeysms_replace_date($message);

                            turkeysms_sendSMS_oneToMany($phone_customer, $message);

                        }

                    }

                }

                $admin_control = esc_html(get_option('turkeysms_cf7_success_admin_control'));

                if (isset($admin_control) && !empty($admin_control) && $admin_control == 1) {

                    $admin_message = (get_option('turkeysms_cf7_list_text_success_admin_' . $form_id));

                    if ($admin_message != '') {

                        $replace = new ReplaceFunction();

                        $message = $replace->turkeysms_cf7_replace_all_var($posted_data, $admin_message);

                        $message = $replace->turkeysms_replace_date($message);

                        turkeysms_sendSMS_oneToMany($phone_admin, $message);

                    }

                }



                $contact_control = esc_html(get_option('turkeysms_cf7_contact_control'));

                if (isset($contact_control) && !empty($contact_control) && $contact_control == 1) {

                    $groupname = (get_option('turkeysms_cf7_list_contact_' . $form_id));

                    if ($groupname != '') {

                        $turkeysms = new TurkeySMS_SMS(get_option("turkeysms_user"), get_option("turkeysms_pass"), get_option("turkeysms_apikey"), get_option('turkeysms_input_smstitle'), get_option("turkeysms_charset"));

                        $firstname_key = (get_option('turkeysms_cf7_list_contact_firstname_' . $form_id));

                        $lastname_key = (get_option('turkeysms_cf7_list_contact_lastname_' . $form_id));

                        $firstname = $posted_data[$firstname_key];

                        $lastname = $posted_data[$lastname_key];

                        $phone_number = $posted_data['telephone'];



                        $turkeysms->addContact($firstname, $lastname, $phone_number, $groupname);

                    }

                }



            }

        }

        return $posted_data;

    }



    /*

     * WC API için gerekli işlemler

     */

    add_filter( 'woocommerce_rest_api_get_rest_namespaces', 'woo_custom_api' );

    function woo_custom_api( $controllers ) {

        $controllers['wc/v3']['custom'] = 'WC_REST_Custom_Controller';

        $controllers['wc/v3']['test'] = 'WC_REST_Custom_Controller';



        return $controllers;

    }



    require_once 'wc-turkeysms-api.php';